summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorWolfgang Hommel <wolfgang.hommel@unibw.de>2022-02-20 17:53:54 +0100
committerWolfgang Hommel <wolfgang.hommel@unibw.de>2022-02-20 17:53:54 +0100
commit02bc1fccae8b464060931f125caae347af33ad3f (patch)
tree26fd7245ab1a64e744363652001efcbea4737f7b /src
parent2c02fc08efba44a68e6387e47747bb28982d3dae (diff)
downloadlibfaketime-02bc1fccae8b464060931f125caae347af33ad3f.tar.gz
Version bump to 0.9.10 (prepares for #366)
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.OSX2
-rw-r--r--src/faketime.c4
-rw-r--r--src/libfaketime.c2
3 files changed, 4 insertions, 4 deletions
diff --git a/src/Makefile.OSX b/src/Makefile.OSX
index 11ea91b..2d7191f 100644
--- a/src/Makefile.OSX
+++ b/src/Makefile.OSX
@@ -56,7 +56,7 @@ INSTALL ?= install
PREFIX ?= /usr/local
CFLAGS += -DFAKE_SLEEP -DFAKE_INTERNAL_CALLS -DPREFIX='"'${PREFIX}'"' $(FAKETIME_COMPILE_CFLAGS) -DMACOS_DYLD_INTERPOSE -DFAKE_SETTIME
-LIB_LDFLAGS += -dynamiclib -current_version 0.9.9 -compatibility_version 0.7
+LIB_LDFLAGS += -dynamiclib -current_version 0.9.10 -compatibility_version 0.7
SONAME = 1
LIBS = libfaketime.${SONAME}.dylib
diff --git a/src/libfaketime.c b/src/libfaketime.c
index b47fcb3..b20a5fa 100644
--- a/src/libfaketime.c
+++ b/src/libfaketime.c
@@ -1,5 +1,5 @@
/*
- * This file is part of libfaketime, version 0.9.9
+ * This file is part of libfaketime, version 0.9.10
*
* libfaketime is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License v2 as published by the
diff --git a/src/faketime.c b/src/faketime.c
index a2faa66..5dd4c0a 100644
--- a/src/faketime.c
+++ b/src/faketime.c
@@ -1,7 +1,7 @@
/*
* libfaketime wrapper command
*
* This file is part of libfaketime, version 0.9.9
*
* libfaketime is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License v2 as published by the
@@ -48,7 +48,7 @@
#include "faketime_common.h"
-const char version[] = "0.9.9";
+const char version[] = "0.9.10";
#if (defined __APPLE__) || (defined __sun)
static const char *date_cmd = "gdate";
@@ -1,7 +1,7 @@
* libfaketime wrapper command
*
- * This file is part of libfaketime, version 0.9.9
+ * This file is part of libfaketime, version 0.9.10
*
* libfaketime is free software; you can redistribute it and/or modify it